# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2016-12-12 19:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oidc_provider', '0020_client__post_logout_redirect_uris'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='refresh_token',
            field=models.CharField(default='', max_length=255, unique=True, verbose_name='Refresh Token'),
            preserve_default=False,
        ),
    ]
